# shine.galaxy_utils

Galaxy morphology modeling utilities.

Factory functions for creating GalSim and JAX-GalSim galaxy objects from
configuration, supporting Sersic and Exponential profiles with ellipticity.

::: shine.galaxy_utils
